@@ -1,3 +1,18 @@
+##############################################################################
+#
+# Copyright (c) 2008 Zope Corporation and Contributors.
+# All Rights Reserved.
+#
+# This software is subject to the provisions of the Zope Public License,
+# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
+# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
+# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
+# FOR A PARTICULAR PURPOSE.
+#
+##############################################################################
+"""Public interfaces.
+"""
 from zope.interface import Interface, Attribute
 
 class IContext(Interface):
@@ -60,6 +75,20 @@ class IDirectives(Interface):
 
         This directive can only be used on class level."""
 
+    def title(title):
+        """Set a human-readable title for a component (e.g. a
+        permission, menu item, etc.).
+
+        This directive expects pure ASCII strings or Unicode and can
+        only be used on a class level."""
+
+    def description(description):
+        """Set a human-readable description for a component (e.g. a
+        permission, menu item, etc.).
+
+        This directive expects pure ASCII strings or Unicode and can
+        only be used on a class level."""
+
     def provides(interface):
         """Explicitly specify with which interface a component will be
         looked up."""
